@@ -3,14 +3,15 @@ Main interface for directconnect service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.directconnect import (
+    from mypy_boto3_directconnect import (
         Client,
         DescribeDirectConnectGatewayAssociationsPaginator,
         DescribeDirectConnectGatewayAttachmentsPaginator,
         DescribeDirectConnectGatewaysPaginator,
         DirectConnectClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -20,14 +21,17 @@ Usage::
     describe_direct_connect_gateway_associations_paginator: DescribeDirectConnectGatewayAssociationsPaginator = client.get_paginator("describe_direct_connect_gateway_associations")
     describe_direct_connect_gateway_attachments_paginator: DescribeDirectConnectGatewayAttachmentsPaginator = client.get_paginator("describe_direct_connect_gateway_attachments")
     describe_direct_connect_gateways_paginator: DescribeDirectConnectGatewaysPaginator = client.get_paginator("describe_direct_connect_gateways")
+    ```
 """
-from mypy_boto3_directconnect.client import DirectConnectClient, DirectConnectClient as Client
-from mypy_boto3_directconnect.paginator import (
+from .client import DirectConnectClient
+from .paginator import (
     DescribeDirectConnectGatewayAssociationsPaginator,
     DescribeDirectConnectGatewayAttachmentsPaginator,
     DescribeDirectConnectGatewaysPaginator,
 )
 
+Client = DirectConnectClient
+
 
 __all__ = (
     "Client",
