@@ -1,16 +1,37 @@
 """
-Main interface for directconnect service type definitions.
+Type annotations for directconnect service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
-    from mypy_boto3.directconnect.type_defs import AssociatedGatewayTypeDef
+    ```python
+    from mypy_boto3_directconnect.type_defs import AcceptDirectConnectGatewayAssociationProposalResultTypeDef
 
-    data: AssociatedGatewayTypeDef = {...}
+    data: AcceptDirectConnectGatewayAssociationProposalResultTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import IO, List, Union
 
+from .literals import (
+    AddressFamilyType,
+    BGPPeerStateType,
+    BGPStatusType,
+    ConnectionStateType,
+    DirectConnectGatewayAssociationProposalStateType,
+    DirectConnectGatewayAssociationStateType,
+    DirectConnectGatewayAttachmentStateType,
+    DirectConnectGatewayAttachmentTypeType,
+    DirectConnectGatewayStateType,
+    GatewayTypeType,
+    HasLogicalRedundancyType,
+    InterconnectStateType,
+    LagStateType,
+    VirtualInterfaceStateType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
@@ -22,14 +43,11 @@ else:
 
 
 __all__ = (
-    "AssociatedGatewayTypeDef",
-    "RouteFilterPrefixTypeDef",
-    "DirectConnectGatewayAssociationTypeDef",
     "AcceptDirectConnectGatewayAssociationProposalResultTypeDef",
-    "BGPPeerTypeDef",
-    "TagTypeDef",
-    "VirtualInterfaceTypeDef",
     "AllocateTransitVirtualInterfaceResultTypeDef",
+    "AssociateMacSecKeyResponseTypeDef",
+    "AssociatedGatewayTypeDef",
+    "BGPPeerTypeDef",
     "ConfirmConnectionResponseTypeDef",
     "ConfirmPrivateVirtualInterfaceResponseTypeDef",
     "ConfirmPublicVirtualInterfaceResponseTypeDef",
@@ -37,10 +55,8 @@ __all__ = (
     "ConnectionTypeDef",
     "ConnectionsTypeDef",
     "CreateBGPPeerResponseTypeDef",
-    "DirectConnectGatewayAssociationProposalTypeDef",
     "CreateDirectConnectGatewayAssociationProposalResultTypeDef",
     "CreateDirectConnectGatewayAssociationResultTypeDef",
-    "DirectConnectGatewayTypeDef",
     "CreateDirectConnectGatewayResultTypeDef",
     "CreateTransitVirtualInterfaceResultTypeDef",
     "DeleteBGPPeerResponseTypeDef",
@@ -49,22 +65,27 @@ __all__ = (
     "DeleteDirectConnectGatewayResultTypeDef",
     "DeleteInterconnectResponseTypeDef",
     "DeleteVirtualInterfaceResponseTypeDef",
-    "LoaTypeDef",
     "DescribeConnectionLoaResponseTypeDef",
     "DescribeDirectConnectGatewayAssociationProposalsResultTypeDef",
     "DescribeDirectConnectGatewayAssociationsResultTypeDef",
-    "DirectConnectGatewayAttachmentTypeDef",
     "DescribeDirectConnectGatewayAttachmentsResultTypeDef",
     "DescribeDirectConnectGatewaysResultTypeDef",
     "DescribeInterconnectLoaResponseTypeDef",
-    "ResourceTagTypeDef",
     "DescribeTagsResponseTypeDef",
+    "DirectConnectGatewayAssociationProposalTypeDef",
+    "DirectConnectGatewayAssociationTypeDef",
+    "DirectConnectGatewayAttachmentTypeDef",
+    "DirectConnectGatewayTypeDef",
+    "DisassociateMacSecKeyResponseTypeDef",
     "InterconnectTypeDef",
     "InterconnectsTypeDef",
     "LagTypeDef",
     "LagsTypeDef",
+    "ListVirtualInterfaceTestHistoryResponseTypeDef",
+    "LoaTypeDef",
     "LocationTypeDef",
     "LocationsTypeDef",
+    "MacSecKeyTypeDef",
     "NewBGPPeerTypeDef",
     "NewPrivateVirtualInterfaceAllocationTypeDef",
     "NewPrivateVirtualInterfaceTypeDef",
@@ -73,135 +94,75 @@ __all__ = (
     "NewTransitVirtualInterfaceAllocationTypeDef",
     "NewTransitVirtualInterfaceTypeDef",
     "PaginatorConfigTypeDef",
+    "ResourceTagTypeDef",
+    "RouteFilterPrefixTypeDef",
+    "StartBgpFailoverTestResponseTypeDef",
+    "StopBgpFailoverTestResponseTypeDef",
+    "TagTypeDef",
     "UpdateDirectConnectGatewayAssociationResultTypeDef",
     "VirtualGatewayTypeDef",
     "VirtualGatewaysTypeDef",
+    "VirtualInterfaceTestHistoryTypeDef",
+    "VirtualInterfaceTypeDef",
     "VirtualInterfacesTypeDef",
 )
 
+AcceptDirectConnectGatewayAssociationProposalResultTypeDef = TypedDict(
+    "AcceptDirectConnectGatewayAssociationProposalResultTypeDef",
+    {
+        "directConnectGatewayAssociation": "DirectConnectGatewayAssociationTypeDef",
+    },
+    total=False,
+)
+
+AllocateTransitVirtualInterfaceResultTypeDef = TypedDict(
+    "AllocateTransitVirtualInterfaceResultTypeDef",
+    {
+        "virtualInterface": "VirtualInterfaceTypeDef",
+    },
+    total=False,
+)
+
+AssociateMacSecKeyResponseTypeDef = TypedDict(
+    "AssociateMacSecKeyResponseTypeDef",
+    {
+        "connectionId": str,
+        "macSecKeys": List["MacSecKeyTypeDef"],
+    },
+    total=False,
+)
+
 AssociatedGatewayTypeDef = TypedDict(
     "AssociatedGatewayTypeDef",
     {
         "id": str,
-        "type": Literal["virtualPrivateGateway", "transitGateway"],
+        "type": GatewayTypeType,
         "ownerAccount": str,
         "region": str,
     },
     total=False,
 )
 
-RouteFilterPrefixTypeDef = TypedDict("RouteFilterPrefixTypeDef", {"cidr": str}, total=False)
-
-DirectConnectGatewayAssociationTypeDef = TypedDict(
-    "DirectConnectGatewayAssociationTypeDef",
-    {
-        "directConnectGatewayId": str,
-        "directConnectGatewayOwnerAccount": str,
-        "associationState": Literal[
-            "associating", "associated", "disassociating", "disassociated", "updating"
-        ],
-        "stateChangeError": str,
-        "associatedGateway": AssociatedGatewayTypeDef,
-        "associationId": str,
-        "allowedPrefixesToDirectConnectGateway": List[RouteFilterPrefixTypeDef],
-        "virtualGatewayId": str,
-        "virtualGatewayRegion": str,
-        "virtualGatewayOwnerAccount": str,
-    },
-    total=False,
-)
-
-AcceptDirectConnectGatewayAssociationProposalResultTypeDef = TypedDict(
-    "AcceptDirectConnectGatewayAssociationProposalResultTypeDef",
-    {"directConnectGatewayAssociation": DirectConnectGatewayAssociationTypeDef},
-    total=False,
-)
-
 BGPPeerTypeDef = TypedDict(
     "BGPPeerTypeDef",
     {
         "bgpPeerId": str,
         "asn": int,
         "authKey": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
+        "addressFamily": AddressFamilyType,
         "amazonAddress": str,
         "customerAddress": str,
-        "bgpPeerState": Literal["verifying", "pending", "available", "deleting", "deleted"],
-        "bgpStatus": Literal["up", "down", "unknown"],
+        "bgpPeerState": BGPPeerStateType,
+        "bgpStatus": BGPStatusType,
         "awsDeviceV2": str,
     },
     total=False,
 )
 
-_RequiredTagTypeDef = TypedDict("_RequiredTagTypeDef", {"key": str})
-_OptionalTagTypeDef = TypedDict("_OptionalTagTypeDef", {"value": str}, total=False)
-
-
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
-    pass
-
-
-VirtualInterfaceTypeDef = TypedDict(
-    "VirtualInterfaceTypeDef",
-    {
-        "ownerAccount": str,
-        "virtualInterfaceId": str,
-        "location": str,
-        "connectionId": str,
-        "virtualInterfaceType": str,
-        "virtualInterfaceName": str,
-        "vlan": int,
-        "asn": int,
-        "amazonSideAsn": int,
-        "authKey": str,
-        "amazonAddress": str,
-        "customerAddress": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
-        "virtualInterfaceState": Literal[
-            "confirming",
-            "verifying",
-            "pending",
-            "available",
-            "down",
-            "deleting",
-            "deleted",
-            "rejected",
-            "unknown",
-        ],
-        "customerRouterConfig": str,
-        "mtu": int,
-        "jumboFrameCapable": bool,
-        "virtualGatewayId": str,
-        "directConnectGatewayId": str,
-        "routeFilterPrefixes": List[RouteFilterPrefixTypeDef],
-        "bgpPeers": List[BGPPeerTypeDef],
-        "region": str,
-        "awsDeviceV2": str,
-        "tags": List[TagTypeDef],
-    },
-    total=False,
-)
-
-AllocateTransitVirtualInterfaceResultTypeDef = TypedDict(
-    "AllocateTransitVirtualInterfaceResultTypeDef",
-    {"virtualInterface": VirtualInterfaceTypeDef},
-    total=False,
-)
-
 ConfirmConnectionResponseTypeDef = TypedDict(
     "ConfirmConnectionResponseTypeDef",
     {
-        "connectionState": Literal[
-            "ordering",
-            "requested",
-            "pending",
-            "available",
-            "down",
-            "deleting",
-            "deleted",
-            "rejected",
-            "unknown",
-        ]
+        "connectionState": ConnectionStateType,
     },
     total=False,
 )
@@ -209,17 +170,7 @@ ConfirmConnectionResponseTypeDef = TypedDict(
 ConfirmPrivateVirtualInterfaceResponseTypeDef = TypedDict(
     "ConfirmPrivateVirtualInterfaceResponseTypeDef",
     {
-        "virtualInterfaceState": Literal[
-            "confirming",
-            "verifying",
-            "pending",
-            "available",
-            "down",
-            "deleting",
-            "deleted",
-            "rejected",
-            "unknown",
-        ]
+        "virtualInterfaceState": VirtualInterfaceStateType,
     },
     total=False,
 )
@@ -227,17 +178,7 @@ ConfirmPrivateVirtualInterfaceResponseTypeDef = TypedDict(
 ConfirmPublicVirtualInterfaceResponseTypeDef = TypedDict(
     "ConfirmPublicVirtualInterfaceResponseTypeDef",
     {
-        "virtualInterfaceState": Literal[
-            "confirming",
-            "verifying",
-            "pending",
-            "available",
-            "down",
-            "deleting",
-            "deleted",
-            "rejected",
-            "unknown",
-        ]
+        "virtualInterfaceState": VirtualInterfaceStateType,
     },
     total=False,
 )
@@ -245,17 +186,7 @@ ConfirmPublicVirtualInterfaceResponseTypeDef = TypedDict(
 ConfirmTransitVirtualInterfaceResponseTypeDef = TypedDict(
     "ConfirmTransitVirtualInterfaceResponseTypeDef",
     {
-        "virtualInterfaceState": Literal[
-            "confirming",
-            "verifying",
-            "pending",
-            "available",
-            "down",
-            "deleting",
-            "deleted",
-            "rejected",
-            "unknown",
-        ]
+        "virtualInterfaceState": VirtualInterfaceStateType,
     },
     total=False,
 )
@@ -266,17 +197,7 @@ ConnectionTypeDef = TypedDict(
         "ownerAccount": str,
         "connectionId": str,
         "connectionName": str,
-        "connectionState": Literal[
-            "ordering",
-            "requested",
-            "pending",
-            "available",
-            "down",
-            "deleting",
-            "deleted",
-            "rejected",
-            "unknown",
-        ],
+        "connectionState": ConnectionStateType,
         "region": str,
         "location": str,
         "bandwidth": str,
@@ -287,100 +208,101 @@ ConnectionTypeDef = TypedDict(
         "awsDevice": str,
         "jumboFrameCapable": bool,
         "awsDeviceV2": str,
-        "hasLogicalRedundancy": Literal["unknown", "yes", "no"],
-        "tags": List[TagTypeDef],
+        "hasLogicalRedundancy": HasLogicalRedundancyType,
+        "tags": List["TagTypeDef"],
         "providerName": str,
+        "macSecCapable": bool,
+        "portEncryptionStatus": str,
+        "encryptionMode": str,
+        "macSecKeys": List["MacSecKeyTypeDef"],
     },
     total=False,
 )
 
 ConnectionsTypeDef = TypedDict(
-    "ConnectionsTypeDef", {"connections": List[ConnectionTypeDef]}, total=False
+    "ConnectionsTypeDef",
+    {
+        "connections": List["ConnectionTypeDef"],
+    },
+    total=False,
 )
 
 CreateBGPPeerResponseTypeDef = TypedDict(
-    "CreateBGPPeerResponseTypeDef", {"virtualInterface": VirtualInterfaceTypeDef}, total=False
-)
-
-DirectConnectGatewayAssociationProposalTypeDef = TypedDict(
-    "DirectConnectGatewayAssociationProposalTypeDef",
+    "CreateBGPPeerResponseTypeDef",
     {
-        "proposalId": str,
-        "directConnectGatewayId": str,
-        "directConnectGatewayOwnerAccount": str,
-        "proposalState": Literal["requested", "accepted", "deleted"],
-        "associatedGateway": AssociatedGatewayTypeDef,
-        "existingAllowedPrefixesToDirectConnectGateway": List[RouteFilterPrefixTypeDef],
-        "requestedAllowedPrefixesToDirectConnectGateway": List[RouteFilterPrefixTypeDef],
+        "virtualInterface": "VirtualInterfaceTypeDef",
     },
     total=False,
 )
 
 CreateDirectConnectGatewayAssociationProposalResultTypeDef = TypedDict(
     "CreateDirectConnectGatewayAssociationProposalResultTypeDef",
-    {"directConnectGatewayAssociationProposal": DirectConnectGatewayAssociationProposalTypeDef},
+    {
+        "directConnectGatewayAssociationProposal": "DirectConnectGatewayAssociationProposalTypeDef",
+    },
     total=False,
 )
 
 CreateDirectConnectGatewayAssociationResultTypeDef = TypedDict(
     "CreateDirectConnectGatewayAssociationResultTypeDef",
-    {"directConnectGatewayAssociation": DirectConnectGatewayAssociationTypeDef},
-    total=False,
-)
-
-DirectConnectGatewayTypeDef = TypedDict(
-    "DirectConnectGatewayTypeDef",
     {
-        "directConnectGatewayId": str,
-        "directConnectGatewayName": str,
-        "amazonSideAsn": int,
-        "ownerAccount": str,
-        "directConnectGatewayState": Literal["pending", "available", "deleting", "deleted"],
-        "stateChangeError": str,
+        "directConnectGatewayAssociation": "DirectConnectGatewayAssociationTypeDef",
     },
     total=False,
 )
 
 CreateDirectConnectGatewayResultTypeDef = TypedDict(
     "CreateDirectConnectGatewayResultTypeDef",
-    {"directConnectGateway": DirectConnectGatewayTypeDef},
+    {
+        "directConnectGateway": "DirectConnectGatewayTypeDef",
+    },
     total=False,
 )
 
 CreateTransitVirtualInterfaceResultTypeDef = TypedDict(
     "CreateTransitVirtualInterfaceResultTypeDef",
-    {"virtualInterface": VirtualInterfaceTypeDef},
+    {
+        "virtualInterface": "VirtualInterfaceTypeDef",
+    },
     total=False,
 )
 
 DeleteBGPPeerResponseTypeDef = TypedDict(
-    "DeleteBGPPeerResponseTypeDef", {"virtualInterface": VirtualInterfaceTypeDef}, total=False
+    "DeleteBGPPeerResponseTypeDef",
+    {
+        "virtualInterface": "VirtualInterfaceTypeDef",
+    },
+    total=False,
 )
 
 DeleteDirectConnectGatewayAssociationProposalResultTypeDef = TypedDict(
     "DeleteDirectConnectGatewayAssociationProposalResultTypeDef",
-    {"directConnectGatewayAssociationProposal": DirectConnectGatewayAssociationProposalTypeDef},
+    {
+        "directConnectGatewayAssociationProposal": "DirectConnectGatewayAssociationProposalTypeDef",
+    },
     total=False,
 )
 
 DeleteDirectConnectGatewayAssociationResultTypeDef = TypedDict(
     "DeleteDirectConnectGatewayAssociationResultTypeDef",
-    {"directConnectGatewayAssociation": DirectConnectGatewayAssociationTypeDef},
+    {
+        "directConnectGatewayAssociation": "DirectConnectGatewayAssociationTypeDef",
+    },
     total=False,
 )
 
 DeleteDirectConnectGatewayResultTypeDef = TypedDict(
     "DeleteDirectConnectGatewayResultTypeDef",
-    {"directConnectGateway": DirectConnectGatewayTypeDef},
+    {
+        "directConnectGateway": "DirectConnectGatewayTypeDef",
+    },
     total=False,
 )
 
 DeleteInterconnectResponseTypeDef = TypedDict(
     "DeleteInterconnectResponseTypeDef",
     {
-        "interconnectState": Literal[
-            "requested", "pending", "available", "down", "deleting", "deleted", "unknown"
-        ]
+        "interconnectState": InterconnectStateType,
     },
     total=False,
 )
@@ -388,36 +310,24 @@ DeleteInterconnectResponseTypeDef = TypedDict(
 DeleteVirtualInterfaceResponseTypeDef = TypedDict(
     "DeleteVirtualInterfaceResponseTypeDef",
     {
-        "virtualInterfaceState": Literal[
-            "confirming",
-            "verifying",
-            "pending",
-            "available",
-            "down",
-            "deleting",
-            "deleted",
-            "rejected",
-            "unknown",
-        ]
+        "virtualInterfaceState": VirtualInterfaceStateType,
     },
     total=False,
 )
 
-LoaTypeDef = TypedDict(
-    "LoaTypeDef",
-    {"loaContent": Union[bytes, IO], "loaContentType": Literal["application/pdf"]},
-    total=False,
-)
-
 DescribeConnectionLoaResponseTypeDef = TypedDict(
-    "DescribeConnectionLoaResponseTypeDef", {"loa": LoaTypeDef}, total=False
+    "DescribeConnectionLoaResponseTypeDef",
+    {
+        "loa": "LoaTypeDef",
+    },
+    total=False,
 )
 
 DescribeDirectConnectGatewayAssociationProposalsResultTypeDef = TypedDict(
     "DescribeDirectConnectGatewayAssociationProposalsResultTypeDef",
     {
         "directConnectGatewayAssociationProposals": List[
-            DirectConnectGatewayAssociationProposalTypeDef
+            "DirectConnectGatewayAssociationProposalTypeDef"
         ],
         "nextToken": str,
     },
@@ -427,12 +337,77 @@ DescribeDirectConnectGatewayAssociationProposalsResultTypeDef = TypedDict(
 DescribeDirectConnectGatewayAssociationsResultTypeDef = TypedDict(
     "DescribeDirectConnectGatewayAssociationsResultTypeDef",
     {
-        "directConnectGatewayAssociations": List[DirectConnectGatewayAssociationTypeDef],
+        "directConnectGatewayAssociations": List["DirectConnectGatewayAssociationTypeDef"],
         "nextToken": str,
     },
     total=False,
 )
 
+DescribeDirectConnectGatewayAttachmentsResultTypeDef = TypedDict(
+    "DescribeDirectConnectGatewayAttachmentsResultTypeDef",
+    {
+        "directConnectGatewayAttachments": List["DirectConnectGatewayAttachmentTypeDef"],
+        "nextToken": str,
+    },
+    total=False,
+)
+
+DescribeDirectConnectGatewaysResultTypeDef = TypedDict(
+    "DescribeDirectConnectGatewaysResultTypeDef",
+    {
+        "directConnectGateways": List["DirectConnectGatewayTypeDef"],
+        "nextToken": str,
+    },
+    total=False,
+)
+
+DescribeInterconnectLoaResponseTypeDef = TypedDict(
+    "DescribeInterconnectLoaResponseTypeDef",
+    {
+        "loa": "LoaTypeDef",
+    },
+    total=False,
+)
+
+DescribeTagsResponseTypeDef = TypedDict(
+    "DescribeTagsResponseTypeDef",
+    {
+        "resourceTags": List["ResourceTagTypeDef"],
+    },
+    total=False,
+)
+
+DirectConnectGatewayAssociationProposalTypeDef = TypedDict(
+    "DirectConnectGatewayAssociationProposalTypeDef",
+    {
+        "proposalId": str,
+        "directConnectGatewayId": str,
+        "directConnectGatewayOwnerAccount": str,
+        "proposalState": DirectConnectGatewayAssociationProposalStateType,
+        "associatedGateway": "AssociatedGatewayTypeDef",
+        "existingAllowedPrefixesToDirectConnectGateway": List["RouteFilterPrefixTypeDef"],
+        "requestedAllowedPrefixesToDirectConnectGateway": List["RouteFilterPrefixTypeDef"],
+    },
+    total=False,
+)
+
+DirectConnectGatewayAssociationTypeDef = TypedDict(
+    "DirectConnectGatewayAssociationTypeDef",
+    {
+        "directConnectGatewayId": str,
+        "directConnectGatewayOwnerAccount": str,
+        "associationState": DirectConnectGatewayAssociationStateType,
+        "stateChangeError": str,
+        "associatedGateway": "AssociatedGatewayTypeDef",
+        "associationId": str,
+        "allowedPrefixesToDirectConnectGateway": List["RouteFilterPrefixTypeDef"],
+        "virtualGatewayId": str,
+        "virtualGatewayRegion": str,
+        "virtualGatewayOwnerAccount": str,
+    },
+    total=False,
+)
+
 DirectConnectGatewayAttachmentTypeDef = TypedDict(
     "DirectConnectGatewayAttachmentTypeDef",
     {
@@ -440,48 +415,41 @@ DirectConnectGatewayAttachmentTypeDef = TypedDict(
         "virtualInterfaceId": str,
         "virtualInterfaceRegion": str,
         "virtualInterfaceOwnerAccount": str,
-        "attachmentState": Literal["attaching", "attached", "detaching", "detached"],
-        "attachmentType": Literal["TransitVirtualInterface", "PrivateVirtualInterface"],
+        "attachmentState": DirectConnectGatewayAttachmentStateType,
+        "attachmentType": DirectConnectGatewayAttachmentTypeType,
         "stateChangeError": str,
     },
     total=False,
 )
 
-DescribeDirectConnectGatewayAttachmentsResultTypeDef = TypedDict(
-    "DescribeDirectConnectGatewayAttachmentsResultTypeDef",
+DirectConnectGatewayTypeDef = TypedDict(
+    "DirectConnectGatewayTypeDef",
     {
-        "directConnectGatewayAttachments": List[DirectConnectGatewayAttachmentTypeDef],
-        "nextToken": str,
+        "directConnectGatewayId": str,
+        "directConnectGatewayName": str,
+        "amazonSideAsn": int,
+        "ownerAccount": str,
+        "directConnectGatewayState": DirectConnectGatewayStateType,
+        "stateChangeError": str,
     },
     total=False,
 )
 
-DescribeDirectConnectGatewaysResultTypeDef = TypedDict(
-    "DescribeDirectConnectGatewaysResultTypeDef",
-    {"directConnectGateways": List[DirectConnectGatewayTypeDef], "nextToken": str},
+DisassociateMacSecKeyResponseTypeDef = TypedDict(
+    "DisassociateMacSecKeyResponseTypeDef",
+    {
+        "connectionId": str,
+        "macSecKeys": List["MacSecKeyTypeDef"],
+    },
     total=False,
 )
 
-DescribeInterconnectLoaResponseTypeDef = TypedDict(
-    "DescribeInterconnectLoaResponseTypeDef", {"loa": LoaTypeDef}, total=False
-)
-
-ResourceTagTypeDef = TypedDict(
-    "ResourceTagTypeDef", {"resourceArn": str, "tags": List[TagTypeDef]}, total=False
-)
-
-DescribeTagsResponseTypeDef = TypedDict(
-    "DescribeTagsResponseTypeDef", {"resourceTags": List[ResourceTagTypeDef]}, total=False
-)
-
 InterconnectTypeDef = TypedDict(
     "InterconnectTypeDef",
     {
         "interconnectId": str,
         "interconnectName": str,
-        "interconnectState": Literal[
-            "requested", "pending", "available", "down", "deleting", "deleted", "unknown"
-        ],
+        "interconnectState": InterconnectStateType,
         "region": str,
         "location": str,
         "bandwidth": str,
@@ -490,15 +458,19 @@ InterconnectTypeDef = TypedDict(
         "awsDevice": str,
         "jumboFrameCapable": bool,
         "awsDeviceV2": str,
-        "hasLogicalRedundancy": Literal["unknown", "yes", "no"],
-        "tags": List[TagTypeDef],
+        "hasLogicalRedundancy": HasLogicalRedundancyType,
+        "tags": List["TagTypeDef"],
         "providerName": str,
     },
     total=False,
 )
 
 InterconnectsTypeDef = TypedDict(
-    "InterconnectsTypeDef", {"interconnects": List[InterconnectTypeDef]}, total=False
+    "InterconnectsTypeDef",
+    {
+        "interconnects": List["InterconnectTypeDef"],
+    },
+    total=False,
 )
 
 LagTypeDef = TypedDict(
@@ -509,25 +481,50 @@ LagTypeDef = TypedDict(
         "lagId": str,
         "ownerAccount": str,
         "lagName": str,
-        "lagState": Literal[
-            "requested", "pending", "available", "down", "deleting", "deleted", "unknown"
-        ],
+        "lagState": LagStateType,
         "location": str,
         "region": str,
         "minimumLinks": int,
         "awsDevice": str,
         "awsDeviceV2": str,
-        "connections": List[ConnectionTypeDef],
+        "connections": List["ConnectionTypeDef"],
         "allowsHostedConnections": bool,
         "jumboFrameCapable": bool,
-        "hasLogicalRedundancy": Literal["unknown", "yes", "no"],
-        "tags": List[TagTypeDef],
+        "hasLogicalRedundancy": HasLogicalRedundancyType,
+        "tags": List["TagTypeDef"],
         "providerName": str,
+        "macSecCapable": bool,
+        "encryptionMode": str,
+        "macSecKeys": List["MacSecKeyTypeDef"],
     },
     total=False,
 )
 
-LagsTypeDef = TypedDict("LagsTypeDef", {"lags": List[LagTypeDef]}, total=False)
+LagsTypeDef = TypedDict(
+    "LagsTypeDef",
+    {
+        "lags": List["LagTypeDef"],
+    },
+    total=False,
+)
+
+ListVirtualInterfaceTestHistoryResponseTypeDef = TypedDict(
+    "ListVirtualInterfaceTestHistoryResponseTypeDef",
+    {
+        "virtualInterfaceTestHistory": List["VirtualInterfaceTestHistoryTypeDef"],
+        "nextToken": str,
+    },
+    total=False,
+)
+
+LoaTypeDef = TypedDict(
+    "LoaTypeDef",
+    {
+        "loaContent": Union[bytes, IO[bytes]],
+        "loaContentType": Literal["application/pdf"],
+    },
+    total=False,
+)
 
 LocationTypeDef = TypedDict(
     "LocationTypeDef",
@@ -537,18 +534,36 @@ LocationTypeDef = TypedDict(
         "region": str,
         "availablePortSpeeds": List[str],
         "availableProviders": List[str],
+        "availableMacSecPortSpeeds": List[str],
     },
     total=False,
 )
 
-LocationsTypeDef = TypedDict("LocationsTypeDef", {"locations": List[LocationTypeDef]}, total=False)
+LocationsTypeDef = TypedDict(
+    "LocationsTypeDef",
+    {
+        "locations": List["LocationTypeDef"],
+    },
+    total=False,
+)
+
+MacSecKeyTypeDef = TypedDict(
+    "MacSecKeyTypeDef",
+    {
+        "secretARN": str,
+        "ckn": str,
+        "state": str,
+        "startOn": str,
+    },
+    total=False,
+)
 
 NewBGPPeerTypeDef = TypedDict(
     "NewBGPPeerTypeDef",
     {
         "asn": int,
         "authKey": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
+        "addressFamily": AddressFamilyType,
         "amazonAddress": str,
         "customerAddress": str,
     },
@@ -557,7 +572,11 @@ NewBGPPeerTypeDef = TypedDict(
 
 _RequiredNewPrivateVirtualInterfaceAllocationTypeDef = TypedDict(
     "_RequiredNewPrivateVirtualInterfaceAllocationTypeDef",
-    {"virtualInterfaceName": str, "vlan": int, "asn": int},
+    {
+        "virtualInterfaceName": str,
+        "vlan": int,
+        "asn": int,
+    },
 )
 _OptionalNewPrivateVirtualInterfaceAllocationTypeDef = TypedDict(
     "_OptionalNewPrivateVirtualInterfaceAllocationTypeDef",
@@ -565,9 +584,9 @@ _OptionalNewPrivateVirtualInterfaceAllocationTypeDef = TypedDict(
         "mtu": int,
         "authKey": str,
         "amazonAddress": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
+        "addressFamily": AddressFamilyType,
         "customerAddress": str,
-        "tags": List[TagTypeDef],
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
@@ -582,7 +601,11 @@ class NewPrivateVirtualInterfaceAllocationTypeDef(
 
 _RequiredNewPrivateVirtualInterfaceTypeDef = TypedDict(
     "_RequiredNewPrivateVirtualInterfaceTypeDef",
-    {"virtualInterfaceName": str, "vlan": int, "asn": int},
+    {
+        "virtualInterfaceName": str,
+        "vlan": int,
+        "asn": int,
+    },
 )
 _OptionalNewPrivateVirtualInterfaceTypeDef = TypedDict(
     "_OptionalNewPrivateVirtualInterfaceTypeDef",
@@ -591,10 +614,10 @@ _OptionalNewPrivateVirtualInterfaceTypeDef = TypedDict(
         "authKey": str,
         "amazonAddress": str,
         "customerAddress": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
+        "addressFamily": AddressFamilyType,
         "virtualGatewayId": str,
         "directConnectGatewayId": str,
-        "tags": List[TagTypeDef],
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
@@ -608,7 +631,11 @@ class NewPrivateVirtualInterfaceTypeDef(
 
 _RequiredNewPublicVirtualInterfaceAllocationTypeDef = TypedDict(
     "_RequiredNewPublicVirtualInterfaceAllocationTypeDef",
-    {"virtualInterfaceName": str, "vlan": int, "asn": int},
+    {
+        "virtualInterfaceName": str,
+        "vlan": int,
+        "asn": int,
+    },
 )
 _OptionalNewPublicVirtualInterfaceAllocationTypeDef = TypedDict(
     "_OptionalNewPublicVirtualInterfaceAllocationTypeDef",
@@ -616,9 +643,9 @@ _OptionalNewPublicVirtualInterfaceAllocationTypeDef = TypedDict(
         "authKey": str,
         "amazonAddress": str,
         "customerAddress": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
-        "routeFilterPrefixes": List[RouteFilterPrefixTypeDef],
-        "tags": List[TagTypeDef],
+        "addressFamily": AddressFamilyType,
+        "routeFilterPrefixes": List["RouteFilterPrefixTypeDef"],
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
@@ -633,7 +660,11 @@ class NewPublicVirtualInterfaceAllocationTypeDef(
 
 _RequiredNewPublicVirtualInterfaceTypeDef = TypedDict(
     "_RequiredNewPublicVirtualInterfaceTypeDef",
-    {"virtualInterfaceName": str, "vlan": int, "asn": int},
+    {
+        "virtualInterfaceName": str,
+        "vlan": int,
+        "asn": int,
+    },
 )
 _OptionalNewPublicVirtualInterfaceTypeDef = TypedDict(
     "_OptionalNewPublicVirtualInterfaceTypeDef",
@@ -641,9 +672,9 @@ _OptionalNewPublicVirtualInterfaceTypeDef = TypedDict(
         "authKey": str,
         "amazonAddress": str,
         "customerAddress": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
-        "routeFilterPrefixes": List[RouteFilterPrefixTypeDef],
-        "tags": List[TagTypeDef],
+        "addressFamily": AddressFamilyType,
+        "routeFilterPrefixes": List["RouteFilterPrefixTypeDef"],
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
@@ -665,8 +696,8 @@ NewTransitVirtualInterfaceAllocationTypeDef = TypedDict(
         "authKey": str,
         "amazonAddress": str,
         "customerAddress": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
-        "tags": List[TagTypeDef],
+        "addressFamily": AddressFamilyType,
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
@@ -681,31 +712,150 @@ NewTransitVirtualInterfaceTypeDef = TypedDict(
         "authKey": str,
         "amazonAddress": str,
         "customerAddress": str,
-        "addressFamily": Literal["ipv4", "ipv6"],
+        "addressFamily": AddressFamilyType,
         "directConnectGatewayId": str,
-        "tags": List[TagTypeDef],
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
 )
 
+ResourceTagTypeDef = TypedDict(
+    "ResourceTagTypeDef",
+    {
+        "resourceArn": str,
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+RouteFilterPrefixTypeDef = TypedDict(
+    "RouteFilterPrefixTypeDef",
+    {
+        "cidr": str,
+    },
+    total=False,
+)
+
+StartBgpFailoverTestResponseTypeDef = TypedDict(
+    "StartBgpFailoverTestResponseTypeDef",
+    {
+        "virtualInterfaceTest": "VirtualInterfaceTestHistoryTypeDef",
+    },
+    total=False,
+)
+
+StopBgpFailoverTestResponseTypeDef = TypedDict(
+    "StopBgpFailoverTestResponseTypeDef",
+    {
+        "virtualInterfaceTest": "VirtualInterfaceTestHistoryTypeDef",
+    },
+    total=False,
+)
+
+_RequiredTagTypeDef = TypedDict(
+    "_RequiredTagTypeDef",
+    {
+        "key": str,
+    },
+)
+_OptionalTagTypeDef = TypedDict(
+    "_OptionalTagTypeDef",
+    {
+        "value": str,
+    },
+    total=False,
+)
+
+
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+    pass
+
+
 UpdateDirectConnectGatewayAssociationResultTypeDef = TypedDict(
     "UpdateDirectConnectGatewayAssociationResultTypeDef",
-    {"directConnectGatewayAssociation": DirectConnectGatewayAssociationTypeDef},
+    {
+        "directConnectGatewayAssociation": "DirectConnectGatewayAssociationTypeDef",
+    },
     total=False,
 )
 
 VirtualGatewayTypeDef = TypedDict(
-    "VirtualGatewayTypeDef", {"virtualGatewayId": str, "virtualGatewayState": str}, total=False
+    "VirtualGatewayTypeDef",
+    {
+        "virtualGatewayId": str,
+        "virtualGatewayState": str,
+    },
+    total=False,
 )
 
 VirtualGatewaysTypeDef = TypedDict(
-    "VirtualGatewaysTypeDef", {"virtualGateways": List[VirtualGatewayTypeDef]}, total=False
+    "VirtualGatewaysTypeDef",
+    {
+        "virtualGateways": List["VirtualGatewayTypeDef"],
+    },
+    total=False,
+)
+
+VirtualInterfaceTestHistoryTypeDef = TypedDict(
+    "VirtualInterfaceTestHistoryTypeDef",
+    {
+        "testId": str,
+        "virtualInterfaceId": str,
+        "bgpPeers": List[str],
+        "status": str,
+        "ownerAccount": str,
+        "testDurationInMinutes": int,
+        "startTime": datetime,
+        "endTime": datetime,
+    },
+    total=False,
+)
+
+VirtualInterfaceTypeDef = TypedDict(
+    "VirtualInterfaceTypeDef",
+    {
+        "ownerAccount": str,
+        "virtualInterfaceId": str,
+        "location": str,
+        "connectionId": str,
+        "virtualInterfaceType": str,
+        "virtualInterfaceName": str,
+        "vlan": int,
+        "asn": int,
+        "amazonSideAsn": int,
+        "authKey": str,
+        "amazonAddress": str,
+        "customerAddress": str,
+        "addressFamily": AddressFamilyType,
+        "virtualInterfaceState": VirtualInterfaceStateType,
+        "customerRouterConfig": str,
+        "mtu": int,
+        "jumboFrameCapable": bool,
+        "virtualGatewayId": str,
+        "directConnectGatewayId": str,
+        "routeFilterPrefixes": List["RouteFilterPrefixTypeDef"],
+        "bgpPeers": List["BGPPeerTypeDef"],
+        "region": str,
+        "awsDeviceV2": str,
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
 )
 
 VirtualInterfacesTypeDef = TypedDict(
-    "VirtualInterfacesTypeDef", {"virtualInterfaces": List[VirtualInterfaceTypeDef]}, total=False
+    "VirtualInterfacesTypeDef",
+    {
+        "virtualInterfaces": List["VirtualInterfaceTypeDef"],
+    },
+    total=False,
 )
